Index: Source/web/FullscreenController.cpp |
diff --git a/Source/web/FullscreenController.cpp b/Source/web/FullscreenController.cpp |
index 94a9ee5766d44f5826590a1ccc3f39ee244a9609..a18101de654d79c6dd6a06de41e8c853cd9a6373 100644 |
--- a/Source/web/FullscreenController.cpp |
+++ b/Source/web/FullscreenController.cpp |
@@ -117,10 +117,10 @@ void FullscreenController::willExitFullScreen() |
if (!fullscreen) |
return; |
if (fullscreen->isFullScreen(*doc)) { |
// When the client exits from full screen we have to call webkitCancelFullScreen to |
// notify the document. While doing that, suppress notifications back to the client. |
m_isCancelingFullScreen = true; |
- fullscreen->webkitCancelFullScreen(); |
+ fullscreen->fullyExitFullscreen(); |
m_isCancelingFullScreen = false; |
fullscreen->webkitWillExitFullScreenForElement(0); |
if (RuntimeEnabledFeatures::overlayFullscreenVideoEnabled() && m_webViewImpl->layerTreeView()) |
@@ -117,10 +117,10 @@ void FullscreenController::willExitFullScreen() |
return; |
if (fullscreen->isFullScreen(*doc)) { |
- // When the client exits from full screen we have to call webkitCancelFullScreen to |
- // notify the document. While doing that, suppress notifications back to the client. |
+ // When the client exits from full screen we have to call fullyExitFullscreen to notify |
+ // the document. While doing that, suppress notifications back to the client. |
m_isCancelingFullScreen = true; |